from findpydeps.findpydeps import main
import sys
if __name__ == "__main__":
	sys.exit(main())